.. Karaage documentation master file, created by
   sphinx-quickstart on Thu Jan 16 14:28:57 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Karaage user documentation
==========================

This is documentation for Karaage 3.

:Date: |today|
:Version: |version|

Contents:

.. toctree::
   :maxdepth: 2

   introduction

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

